pub type FPTR = usize;Expand description
A function pointer with the Amiga calling convention
Parameters and the return value are passed in the CPU registers (this is not the āCā calling convention). The ROM kernel manuals have documented which registers to use.